from django.apps import AppConfig


class DittoTwitterConfig(AppConfig):
    name = "ditto.twitter"
    verbose_name = "Ditto Twitter"
